/*
 * ApplicationServer.cs
 *
 * Testing Framework
 * Version: 1.0
 *
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved
 *
 * Authors: real_vg, TCSDEVELOPER
 */

namespace TopCoder.Test.Framework.Servers
{
    /// <summary>
    /// Provides an abstract base class for all the classes representing
    /// an application server to be used when running tests.
    /// </summary>
    ///
    /// <remarks>
    /// This class extends <see cref="Server"/> by adding <see cref="DeploymentDirectory"/>
    /// which specifies the directory the application should be deployed to.
    /// </remarks>
    ///
    /// <threadsafety static="false" instance="false"/>
    public abstract class ApplicationServer : Server
    {
        /// <summary>
        /// A string constant that represents the name (key) of the option, used by derived classes,
        /// for getting the directory the application should be deployed to.
        /// </summary>
        ///
        /// <remarks>
        /// Note that derived classes can treat options in any way they like to do.
        /// The most simple way this option can be used is copying the files
        /// specified by the SourceFiles property to the directory specified by this option.
        /// </remarks>
        public static readonly string DEPLOYMENT_DIR = "deployment_dir";

        /// <summary>
        /// Gets the directory the application should be deployed to.
        /// </summary>
        ///
        /// <value>
        /// The directory the application should be deployed to.
        /// </value>
        ///
        /// <exception cref="ServerException">
        /// The value doesn't exist.
        /// </exception>
        public string DeploymentDirectory
        {
            get
            {
                return OptionHelper.GetString(DEPLOYMENT_DIR, Options, false);
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="ApplicationServer"/> class.
        /// </summary>
        protected ApplicationServer()
        {
            // do nothing
        }
    }
}
